==> owncloud-10.0.7.tgz: owncloud/lib/l10n/id.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Tidak dapat menulis kedalam direktori \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Hal ini biasanya dapat diperbaiki dengan memberikan akses tulis bagi situs web ke direktori config",
    "See %s" : "Lihat %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Hal ini biasanya dapat diperbaiki dengan %s memberikan akses tulis bagi situs web ke %s direktori config.",
    "Sample configuration detected" : "Konfigurasi sampel ditemukan",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Ditemukan bahwa konfigurasi sampel telah disalin. Hal ini dapat merusak instalasi Anda dan tidak didukung. Silahkan baca dokumentasi sebelum melakukan perubahan pada config.php",
    "PHP %s or higher is required." : "Diperlukan PHP %s atau yang lebih tinggi.",
    "PHP with a version lower than %s is required." : "Diperlukan PHP dengan versi yang lebh rendah dari %s.",
    "Following databases are supported: %s" : "Berikut adalah basis data yang didukung: %s",
    "The command line tool %s could not be found" : "Alat baris perintah %s tidak ditemukan",
    "The library %s is not available." : "Pustaka %s tidak tersedia.",
    "Library %s with a version higher than %s is required - available version %s." : "Diperlukan pustaka %s dengan versi yang lebih tinggi dari %s - versi yang tersedia %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Diperlukan pustaka %s dengan versi yang lebih rendah dari %s - versi yang tersedia %s.",
    "Following platforms are supported: %s" : "Berikut adalah platform yang didukung: %s",
    "ownCloud %s or higher is required." : "Diperlukan ownCloud %s atau yang lebih tinggi.",
    "ownCloud %s or lower is required." : "ownCloud %s atau yang lebih rendah diperlukan.",
    "Unknown filetype" : "Tipe berkas tak dikenal",
    "Invalid image" : "Gambar tidak sah",
    "today" : "hari ini",
    "yesterday" : "kemarin",
    "_%n day ago_::_%n days ago_" : ["%n hari yang lalu"],
    "last month" : "bulan kemarin",
    "_%n month ago_::_%n months ago_" : ["%n bulan yang lalu"],
    "last year" : "tahun kemarin",
    "_%n year ago_::_%n years ago_" : ["%n tahun yang lalu"],
    "_%n hour ago_::_%n hours ago_" : ["%n jam yang lalu"],
    "_%n minute ago_::_%n minutes ago_" : ["%n menit yang lalu"],
    "seconds ago" : "beberapa detik yang lalu",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul dengan id: %s tidak ada. Mohon aktifkan modul tersebut di pengaturan aplikasi Anda atau hubungi administrator.",
    "Builtin" : "Internal",
    "None" : "Tidak ada",
    "Username and password" : "Nama pengguna dan sandi",
    "Username" : "Nama pengguna",
    "Password" : "Kata Sandi",
    "Empty filename is not allowed" : "Nama berkas kosong tidak diperbolehkan",
    "Dot files are not allowed" : "Berkas titik tidak diperbolehkan",
    "4-byte characters are not supported in file names" : "Karakter 4 byte tidak didukung dalam nama berkas",
    "File name is a reserved word" : "Nama berkas merupakan kata yang disediakan",
    "File name contains at least one invalid character" : "Nama berkas berisi setidaknya satu karakter yang tidak sah.",
    "File name is too long" : "Nama berkas terlalu panjang",
    "App directory already exists" : "Direktori Apl sudah ada",
    "Can't create app folder. Please fix permissions. %s" : "Tidak dapat membuat folder apl. Silakan perbaiki perizinan. %s",
    "Archive does not contain a directory named %s" : "Arsip tidak berisi direktori yang bernama %s",
    "No source specified when installing app" : "Tidak ada sumber yang ditentukan saat menginstal apl",
    "No href specified when installing app from http" : "Href tidak ditentukan saat menginstal apl dari http",
    "No path specified when installing app from local file" : "Lokasi tidak ditentukan saat menginstal apl dari berkas lokal",
    "Archives of type %s are not supported" : "Arsip dengan tipe %s tidak didukung",
    "Failed to open archive when installing app" : "Gagal membuka arsip saat menginstal apl",
    "App does not provide an info.xml file" : "Apl tidak menyediakan berkas info.xml",
    "App can't be installed because of not allowed code in the App" : "Apl tidak dapat diinstal karena terdapat kode yang tidak diizinkan didalam Apl",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Apl tidak dapat diinstal karena tidak kompatibel dengan versi ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Apl tidak dapat diinstal karena mengandung tag <shipped>true</shipped> yang tidak diizinkan untuk apl yang bukan bawaan.",
    "Apps" : "Aplikasi",
    "General" : "Umum",
    "Storage" : "Penyimpanan",
    "Security" : "Keamanan",
    "Encryption" : "Enkripsi",
    "Sharing" : "Berbagi",
    "Search" : "Cari",
    "Updates" : "Pembaruan",
    "%s enter the database username." : "%s masukkan nama pengguna basis data.",
    "%s enter the database name." : "%s masukkan nama basis data.",
    "%s you may not use dots in the database name" : "%s anda tidak boleh menggunakan karakter titik pada nama basis data",
    "Oracle connection could not be established" : "Koneksi Oracle tidak dapat dibuat",
    "Oracle username and/or password not valid" : "Nama pengguna dan/atau sandi Oracle tidak sah",
    "DB Error: \"%s\"" : "Kesalahan Basis Data: \"%s\"",
    "Offending command was: \"%s\"" : "Perintah yang bermasalah: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Anda harus memasukkan akun yang sudah ada atau administrator.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Perintah yang bermasalah: \"%s\", nama pengguna: %s, sandi: %s",
    "PostgreSQL username and/or password not valid" : "Nama pengguna dan/atau sandi PostgreSQL tidak valid",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X tidak didukung dan %s tidak akan bekerja dengan baik pada platform ini. Gunakan dengan resiko Anda sendiri!",
    "For the best results, please consider using a GNU/Linux server instead." : "Untuk hasil terbaik, pertimbangkan untuk menggunakan server GNU/Linux sebagai gantinya. ",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Kelihatannya instansi %s ini berjalan di lingkungan PHP 32-bit dan open_basedir telah dikonfigurasi di php.ini. Hal ini akan menyebabkan masalah dengan berkas lebih dari 4 GB dan sangat tidak disarankan.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mohon hapus pengaturan open_basedir didalam php.ini atau beralih ke PHP 64-bit.",
    "Set an admin username." : "Tetapkan nama pengguna admin.",
    "Set an admin password." : "Tetapkan sandi admin.",
    "Can't create or write into the data directory %s" : "Tidak dapat membuat atau menulis kedalam direktori data %s",
    "Invalid Federated Cloud ID" : "Federated Cloud ID tidak sah",
    "%s shared »%s« with you" : "%s membagikan »%s« dengan anda",
    "%s via %s" : "%s melalui %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Gagal berbagi %s, karena backend tidak mengizinkan berbagi dengan tipe %i",
    "Sharing %s failed, because the file does not exist" : "Gagal membagikan %s, karena berkas tidak ada",
    "You are not allowed to share %s" : "Anda tidak diizinkan untuk membagikan %s",
    "Sharing %s failed, because you can not share with yourself" : "Berbagi %s gagal, karena Anda tidak dapat berbagi dengan diri sendiri",
    "Sharing %s failed, because the user %s does not exist" : "Gagal membagikan %s, karena pengguna %s tidak ada",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Gagal membagikan %s, karena pengguna %s bukan merupakan anggota dari grup yang %s ikuti",
    "Sharing %s failed, because this item is already shared with %s" : "Gagal membagkan %s, karena item ini sudah dibagikan dengan %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Berbagi %s gagal karena item ini sudah dibagikan dengan pengguna %s",
    "Sharing %s failed, because the group %s does not exist" : "Gagal membagikan %s, karena grup %s tidak ada",
    "Sharing %s failed, because %s is not a member of the group %s" : "Gagal membagikan %s, karena %s bukan anggota dari grup %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Anda perlu memberikan sandi untuk membuat tautan publik, hanya tautan yang terlindungi yang diizinkan",
    "Sharing %s failed, because sharing with links is not allowed" : "Gagal membagikan %s, karena berbag dengan tautan tidak diizinkan",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Berbagi %s gagal, tidak menemukan %s, kemungkinan saat ini server tidak dapat dijangkau.",
    "Share type %s is not valid for %s" : "Barbagi tipe %s tidak sah untuk %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Pengaturan perizinan untuk %s gagal, karena karena izin melebihi izin yang diberikan untuk %s",
    "Setting permissions for %s failed, because the item was not found" : "Pengaturan perizinan untuk %s gagal, karena item tidak ditemukan",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Tidak dapat menyetel tanggal kadaluarsa. Pembagian tidak dapat kadaluarsa lebih lambat dari %s setelah mereka dibagikan.",
    "Cannot set expiration date. Expiration date is in the past" : "Tidak dapat menyetel tanggal kadaluarsa. Tanggal kadaluarsa dimasa lalu",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Tidak dapat mengosongkan tanggal berakhir. Berbagi harus memiliki tanggal berakhir.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend berbagi %s harus mengimplementasi antarmuka OCP\\Share_Backend",
    "Sharing backend %s not found" : "Backend berbagi %s tidak ditemukan",
    "Sharing backend for %s not found" : "Backend berbagi untuk %s tidak ditemukan",
    "Sharing failed, because the user %s is the original sharer" : "Berbagi gagal, karena pengguna %s adalah pembagi awal",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Gagal membagikan %s, karena izin melebihi izin yang diberikan untuk %s",
    "Sharing %s failed, because resharing is not allowed" : "Gagal berbagi %s, karena membagikan ulang tidak diizinkan",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Berbagi %s gagal, karena backend berbagi untuk %s tidak menemukan sumbernya",
    "Sharing %s failed, because the file could not be found in the file cache" : "Gagal berbagi %s, karena berkas tidak ditemukan di berkas cache",
    "Could not find category \"%s\"" : "Tidak menemukan kategori \"%s\"",
    "A valid username must be provided" : "Tuliskan nama pengguna yang valid",
    "A valid password must be provided" : "Tuliskan sandi yang valid",
    "The username is already being used" : "Nama pengguna ini telah digunakan",
    "Help" : "Bantuan",
    "Settings" : "Pengaturan",
    "Users" : "Pengguna",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Aplikasi \"%s\" tidak dapat diinstal karena dependensi berikut belum terpenuhi: %s",
    "web services under your control" : "layanan web dalam kendali anda",
    "File is currently busy, please try again later" : "Berkas sedang sibuk, mohon coba lagi nanti",
    "Can't read file" : "Tidak dapat membaca berkas",
    "Application is not enabled" : "Aplikasi tidak diaktifkan",
    "Authentication error" : "Galat saat otentikasi",
    "Token expired. Please reload page." : "Token sudah kedaluwarsa. Silakan muat ulang halaman.",
    "Unknown user" : "Pengguna tidak dikenal",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Tidak ada driver (sqlite, mysql, or postgresql) yang terinstal.",
    "Cannot write into \"config\" directory" : "Tidak dapat menulis kedalam direktori \"config\"",
    "Cannot write into \"apps\" directory" : "Tidak dapat menulis kedalam direktori \"apps\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Hal ini biasanya dapat diperbaiki dengan %s memberikan akses tulis bagi situs web ke %s direktori apps atau menonaktifkan toko aplikasi didalam berkas config.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Perizinan biasanya dapat diperbaiki dengan %s memberikan akses tulis bagi situs web ke %s direktori root.",
    "Setting locale to %s failed" : "Pengaturan lokal ke %s gagal",
    "Please install one of these locales on your system and restart your webserver." : "Mohon instal paling tidak satu lokal pada sistem Anda dan jalankan ulang server web.",
    "Please ask your server administrator to install the module." : "Mohon tanyakan administrator Anda untuk menginstal module.",
    "PHP module %s not installed." : "Module PHP %s tidak terinstal.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Pengaturan PHP \"%s\" tidak diatur ke \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Menyesuaikan pengaturan ini dalam php.ini akan menyebabkan ownCloud berjalan kembali",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload diatur menjadi \"%s\" bukan nilai yang diharapkan \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Untuk memperbaiki masalah ini, atur <code>mbstring.func_overload</code> menjadi <code>0</code> pada berkas php.ini Anda",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Tampaknya PHP diatur untuk memotong inline doc blocks. Hal ini akan menyebabkan beberapa aplikasi inti menjadi tidak dapat diakses.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hal ini kemungkinan disebabkan oleh cache/akselerator seperti Zend OPcache atau eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Modul PHP telah terinstal, tetapi mereka terlihat tidak ada?",
    "Please ask your server administrator to restart the web server." : "Mohon minta administrator Anda untuk menjalankan ulang server web.",
    "PostgreSQL >= 9 required" : "Diperlukan PostgreSQL >= 9",
    "Please upgrade your database version" : "Mohon perbarui versi basis data Anda",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mohon ubah perizinan menjadi 0770 sehingga direktori tersebut tidak dapat dilihat oleh pengguna lain.",
    "Check the value of \"datadirectory\" in your configuration" : "Periksa nilai \"datadirectory\" di konfigurasi Anda",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Mohon periksa apakah direktori data berisi sebuah berkas \".ocdata\" di direktori induknya.",
    "Could not obtain lock type %d on \"%s\"." : "Tidak bisa memperoleh jenis kunci %d pada \"%s\".",
    "Storage is temporarily not available" : "Penyimpanan sementara ini tidak tersedia"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.10.tgz: owncloud/lib/l10n/id.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Tidak dapat menulis kedalam direktori \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Hal ini biasanya dapat diperbaiki dengan memberikan akses tulis bagi situs web ke direktori config",
    "See %s" : "Lihat %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Hal ini biasanya dapat diperbaiki dengan %s memberikan akses tulis bagi situs web ke %s direktori config.",
    "Sample configuration detected" : "Konfigurasi sampel ditemukan",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Ditemukan bahwa konfigurasi sampel telah disalin. Hal ini dapat merusak instalasi Anda dan tidak didukung. Silahkan baca dokumentasi sebelum melakukan perubahan pada config.php",
    "PHP %s or higher is required." : "Diperlukan PHP %s atau yang lebih tinggi.",
    "PHP with a version lower than %s is required." : "Diperlukan PHP dengan versi yang lebh rendah dari %s.",
    "Following databases are supported: %s" : "Berikut adalah basis data yang didukung: %s",
    "The command line tool %s could not be found" : "Alat baris perintah %s tidak ditemukan",
    "The library %s is not available." : "Pustaka %s tidak tersedia.",
    "Library %s with a version higher than %s is required - available version %s." : "Diperlukan pustaka %s dengan versi yang lebih tinggi dari %s - versi yang tersedia %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Diperlukan pustaka %s dengan versi yang lebih rendah dari %s - versi yang tersedia %s.",
    "Following platforms are supported: %s" : "Berikut adalah platform yang didukung: %s",
    "ownCloud %s or higher is required." : "Diperlukan ownCloud %s atau yang lebih tinggi.",
    "ownCloud %s or lower is required." : "ownCloud %s atau yang lebih rendah diperlukan.",
    "Unknown filetype" : "Tipe berkas tak dikenal",
    "Invalid image" : "Gambar tidak sah",
    "today" : "hari ini",
    "yesterday" : "kemarin",
    "_%n day ago_::_%n days ago_" : ["%n hari yang lalu"],
    "last month" : "bulan kemarin",
    "_%n month ago_::_%n months ago_" : ["%n bulan yang lalu"],
    "last year" : "tahun kemarin",
    "_%n year ago_::_%n years ago_" : ["%n tahun yang lalu"],
    "_%n hour ago_::_%n hours ago_" : ["%n jam yang lalu"],
    "_%n minute ago_::_%n minutes ago_" : ["%n menit yang lalu"],
    "seconds ago" : "beberapa detik yang lalu",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul dengan id: %s tidak ada. Mohon aktifkan modul tersebut di pengaturan aplikasi Anda atau hubungi administrator.",
    "Builtin" : "Internal",
    "None" : "Tidak ada",
    "Username and password" : "Nama pengguna dan sandi",
    "Username" : "Nama pengguna",
    "Password" : "Kata Sandi",
    "Empty filename is not allowed" : "Nama berkas kosong tidak diperbolehkan",
    "Dot files are not allowed" : "Berkas titik tidak diperbolehkan",
    "4-byte characters are not supported in file names" : "Karakter 4 byte tidak didukung dalam nama berkas",
    "File name is a reserved word" : "Nama berkas merupakan kata yang disediakan",
    "File name contains at least one invalid character" : "Nama berkas berisi setidaknya satu karakter yang tidak sah.",
    "File name is too long" : "Nama berkas terlalu panjang",
    "App directory already exists" : "Direktori Apl sudah ada",
    "Can't create app folder. Please fix permissions. %s" : "Tidak dapat membuat folder apl. Silakan perbaiki perizinan. %s",
    "Archive does not contain a directory named %s" : "Arsip tidak berisi direktori yang bernama %s",
    "No source specified when installing app" : "Tidak ada sumber yang ditentukan saat menginstal apl",
    "No href specified when installing app from http" : "Href tidak ditentukan saat menginstal apl dari http",
    "No path specified when installing app from local file" : "Lokasi tidak ditentukan saat menginstal apl dari berkas lokal",
    "Archives of type %s are not supported" : "Arsip dengan tipe %s tidak didukung",
    "Failed to open archive when installing app" : "Gagal membuka arsip saat menginstal apl",
    "App does not provide an info.xml file" : "Apl tidak menyediakan berkas info.xml",
    "App can't be installed because of not allowed code in the App" : "Apl tidak dapat diinstal karena terdapat kode yang tidak diizinkan didalam Apl",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Apl tidak dapat diinstal karena tidak kompatibel dengan versi ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Apl tidak dapat diinstal karena mengandung tag <shipped>true</shipped> yang tidak diizinkan untuk apl yang bukan bawaan.",
    "Apps" : "Aplikasi",
    "General" : "Umum",
    "Storage" : "Penyimpanan",
    "Security" : "Keamanan",
    "Encryption" : "Enkripsi",
    "Sharing" : "Berbagi",
    "Search" : "Cari",
    "Updates" : "Pembaruan",
    "%s enter the database username." : "%s masukkan nama pengguna basis data.",
    "%s enter the database name." : "%s masukkan nama basis data.",
    "%s you may not use dots in the database name" : "%s anda tidak boleh menggunakan karakter titik pada nama basis data",
    "Oracle connection could not be established" : "Koneksi Oracle tidak dapat dibuat",
    "Oracle username and/or password not valid" : "Nama pengguna dan/atau sandi Oracle tidak sah",
    "DB Error: \"%s\"" : "Kesalahan Basis Data: \"%s\"",
    "Offending command was: \"%s\"" : "Perintah yang bermasalah: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Anda harus memasukkan akun yang sudah ada atau administrator.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Perintah yang bermasalah: \"%s\", nama pengguna: %s, sandi: %s",
    "PostgreSQL username and/or password not valid" : "Nama pengguna dan/atau sandi PostgreSQL tidak valid",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X tidak didukung dan %s tidak akan bekerja dengan baik pada platform ini. Gunakan dengan resiko Anda sendiri!",
    "For the best results, please consider using a GNU/Linux server instead." : "Untuk hasil terbaik, pertimbangkan untuk menggunakan server GNU/Linux sebagai gantinya. ",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Kelihatannya instansi %s ini berjalan di lingkungan PHP 32-bit dan open_basedir telah dikonfigurasi di php.ini. Hal ini akan menyebabkan masalah dengan berkas lebih dari 4 GB dan sangat tidak disarankan.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mohon hapus pengaturan open_basedir didalam php.ini atau beralih ke PHP 64-bit.",
    "Set an admin username." : "Tetapkan nama pengguna admin.",
    "Set an admin password." : "Tetapkan sandi admin.",
    "Can't create or write into the data directory %s" : "Tidak dapat membuat atau menulis kedalam direktori data %s",
    "Invalid Federated Cloud ID" : "Federated Cloud ID tidak sah",
    "%s shared »%s« with you" : "%s membagikan »%s« dengan anda",
    "%s via %s" : "%s melalui %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Gagal berbagi %s, karena backend tidak mengizinkan berbagi dengan tipe %i",
    "Sharing %s failed, because the file does not exist" : "Gagal membagikan %s, karena berkas tidak ada",
    "You are not allowed to share %s" : "Anda tidak diizinkan untuk membagikan %s",
    "Sharing %s failed, because you can not share with yourself" : "Berbagi %s gagal, karena Anda tidak dapat berbagi dengan diri sendiri",
    "Sharing %s failed, because the user %s does not exist" : "Gagal membagikan %s, karena pengguna %s tidak ada",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Gagal membagikan %s, karena pengguna %s bukan merupakan anggota dari grup yang %s ikuti",
    "Sharing %s failed, because this item is already shared with %s" : "Gagal membagkan %s, karena item ini sudah dibagikan dengan %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Berbagi %s gagal karena item ini sudah dibagikan dengan pengguna %s",
    "Sharing %s failed, because the group %s does not exist" : "Gagal membagikan %s, karena grup %s tidak ada",
    "Sharing %s failed, because %s is not a member of the group %s" : "Gagal membagikan %s, karena %s bukan anggota dari grup %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Anda perlu memberikan sandi untuk membuat tautan publik, hanya tautan yang terlindungi yang diizinkan",
    "Sharing %s failed, because sharing with links is not allowed" : "Gagal membagikan %s, karena berbag dengan tautan tidak diizinkan",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Berbagi %s gagal, tidak menemukan %s, kemungkinan saat ini server tidak dapat dijangkau.",
    "Share type %s is not valid for %s" : "Barbagi tipe %s tidak sah untuk %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Pengaturan perizinan untuk %s gagal, karena karena izin melebihi izin yang diberikan untuk %s",
    "Setting permissions for %s failed, because the item was not found" : "Pengaturan perizinan untuk %s gagal, karena item tidak ditemukan",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Tidak dapat menyetel tanggal kadaluarsa. Pembagian tidak dapat kadaluarsa lebih lambat dari %s setelah mereka dibagikan.",
    "Cannot set expiration date. Expiration date is in the past" : "Tidak dapat menyetel tanggal kadaluarsa. Tanggal kadaluarsa dimasa lalu",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Tidak dapat mengosongkan tanggal berakhir. Berbagi harus memiliki tanggal berakhir.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend berbagi %s harus mengimplementasi antarmuka OCP\\Share_Backend",
    "Sharing backend %s not found" : "Backend berbagi %s tidak ditemukan",
    "Sharing backend for %s not found" : "Backend berbagi untuk %s tidak ditemukan",
    "Sharing failed, because the user %s is the original sharer" : "Berbagi gagal, karena pengguna %s adalah pembagi awal",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Gagal membagikan %s, karena izin melebihi izin yang diberikan untuk %s",
    "Sharing %s failed, because resharing is not allowed" : "Gagal berbagi %s, karena membagikan ulang tidak diizinkan",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Berbagi %s gagal, karena backend berbagi untuk %s tidak menemukan sumbernya",
    "Sharing %s failed, because the file could not be found in the file cache" : "Gagal berbagi %s, karena berkas tidak ditemukan di berkas cache",
    "Could not find category \"%s\"" : "Tidak menemukan kategori \"%s\"",
    "A valid username must be provided" : "Tuliskan nama pengguna yang valid",
    "A valid password must be provided" : "Tuliskan sandi yang valid",
    "The username is already being used" : "Nama pengguna ini telah digunakan",
    "Help" : "Bantuan",
    "Settings" : "Pengaturan",
    "Users" : "Pengguna",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Aplikasi \"%s\" tidak dapat diinstal karena dependensi berikut belum terpenuhi: %s",
    "web services under your control" : "layanan web dalam kendali anda",
    "File is currently busy, please try again later" : "Berkas sedang sibuk, mohon coba lagi nanti",
    "Can't read file" : "Tidak dapat membaca berkas",
    "Application is not enabled" : "Aplikasi tidak diaktifkan",
    "Authentication error" : "Galat saat otentikasi",
    "Token expired. Please reload page." : "Token sudah kedaluwarsa. Silakan muat ulang halaman.",
    "Unknown user" : "Pengguna tidak dikenal",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Tidak ada driver (sqlite, mysql, or postgresql) yang terinstal.",
    "Cannot write into \"config\" directory" : "Tidak dapat menulis kedalam direktori \"config\"",
    "Cannot write into \"apps\" directory" : "Tidak dapat menulis kedalam direktori \"apps\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Hal ini biasanya dapat diperbaiki dengan %s memberikan akses tulis bagi situs web ke %s direktori apps atau menonaktifkan toko aplikasi didalam berkas config.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Perizinan biasanya dapat diperbaiki dengan %s memberikan akses tulis bagi situs web ke %s direktori root.",
    "Setting locale to %s failed" : "Pengaturan lokal ke %s gagal",
    "Please install one of these locales on your system and restart your webserver." : "Mohon instal paling tidak satu lokal pada sistem Anda dan jalankan ulang server web.",
    "Please ask your server administrator to install the module." : "Mohon tanyakan administrator Anda untuk menginstal module.",
    "PHP module %s not installed." : "Module PHP %s tidak terinstal.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Pengaturan PHP \"%s\" tidak diatur ke \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Menyesuaikan pengaturan ini dalam php.ini akan menyebabkan ownCloud berjalan kembali",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload diatur menjadi \"%s\" bukan nilai yang diharapkan \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Untuk memperbaiki masalah ini, atur <code>mbstring.func_overload</code> menjadi <code>0</code> pada berkas php.ini Anda",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Tampaknya PHP diatur untuk memotong inline doc blocks. Hal ini akan menyebabkan beberapa aplikasi inti menjadi tidak dapat diakses.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hal ini kemungkinan disebabkan oleh cache/akselerator seperti Zend OPcache atau eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Modul PHP telah terinstal, tetapi mereka terlihat tidak ada?",
    "Please ask your server administrator to restart the web server." : "Mohon minta administrator Anda untuk menjalankan ulang server web.",
    "PostgreSQL >= 9 required" : "Diperlukan PostgreSQL >= 9",
    "Please upgrade your database version" : "Mohon perbarui versi basis data Anda",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mohon ubah perizinan menjadi 0770 sehingga direktori tersebut tidak dapat dilihat oleh pengguna lain.",
    "Check the value of \"datadirectory\" in your configuration" : "Periksa nilai \"datadirectory\" di konfigurasi Anda",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Mohon periksa apakah direktori data berisi sebuah berkas \".ocdata\" di direktori induknya.",
    "Could not obtain lock type %d on \"%s\"." : "Tidak bisa memperoleh jenis kunci %d pada \"%s\".",
    "Storage is temporarily not available" : "Penyimpanan sementara ini tidak tersedia",
    "A safe home for all your data" : "Sebuah rumah yang aman untuk semua data Anda",
    "Imprint" : "Jejak",
    "__language_name__" : "__language_name__"
},
"nplurals=1; plural=0;");
